import snabbdom, { Fragment } from '@servicenow/ui-renderer-snabbdom';

const { createElementFromNode } = snabbdom;

export default (state, { updateProperties, dispatch }) => {
	//┌─────────────────────────────────────────────────────────────
	//! Scoped Constants
	//└─────────────────────────────────────────────────────────────
	const { size, spin, def, componentId } = state.properties;
	const BASE_FONT_SIZE = 16;
	const ICON_SIZES = {
		xs: 10,
		sm: 12,
		md: 16,
		lg: 24,
		xl: 32,
	};

	const getFaIcon = () => {
		const wrapper = document.createElement('SPAN');
		const iconSize = ICON_SIZES[size];
		const iconRems = iconSize / BASE_FONT_SIZE;

		if (!def) {
			return null;
		}

		const { icon } = def;

		if (!icon) {
			return null;
		}

		const viewBox = `0 0 ${icon[0]} ${icon[1]}`;
		const svgPathData = icon[4];
		const svgPath = svgPathData ? `<path xmlns="http://www.w3.org/2000/svg" d="${svgPathData}"></path>` : '';
		const svgTemplate = icon[5] || '';

		wrapper.innerHTML = `<svg
			xmlns="http://www.w3.org/2000/svg"
			aria-hidden="true"
			viewBox="${viewBox}"
			id="${componentId}"
			style="width: ${iconRems}rem; height: ${iconRems}rem; fill: currentColor;"
			${spin ? 'class="-spin"' : ''}>
				${svgPath}
				${svgTemplate}
			</svg>
		`;

		const vnode = createElementFromNode(wrapper);

		return vnode.children[0];
	};

	return <Fragment>{getFaIcon()}</Fragment>;
};
